@@ -237,8 +237,6 @@ bitflags! {
             target_os = "netbsd",
             target_os = "openbsd",
             target_os = "redox",
-            // TODO: Enable s390x once <https://github.com/rust-lang/libc/pull/2395> lands.
-            target_arch = "s390x",
         )))]
         const SYNC = c::MAP_SYNC;
         /// `MAP_UNINITIALIZED`
@@ -390,11 +388,7 @@ pub enum Advice {
     #[cfg(any(target_os = "android", target_os = "linux"))]
     LinuxHwPoison = c::MADV_HWPOISON,
     /// `MADV_SOFT_OFFLINE`
-    // TODO: Enable riscv once <https://github.com/rust-lang/libc/pull/2391> lands.
-    #[cfg(all(
-        not(target_arch = "riscv64"),
-        any(target_os = "android", target_os = "linux")
-    ))]
+    #[cfg(any(target_os = "android", target_os = "linux"))]
     LinuxSoftOffline = c::MADV_SOFT_OFFLINE,
     /// `MADV_MERGEABLE`
     #[cfg(any(target_os = "android", target_os = "linux"))]
